@@ -3,6 +3,10 @@ import os
 import re
 
 import requests
+from packaging.version import InvalidVersion
+
+from .Version import Version
+from .__about__ import __version__
 # this class basically corresponds to something (often a website) which holds
 # projects (usually a bunch). often this is a github-like website, so we subclass session
 # but this also maybe something special, which either way can be used as a source of version
@@ -10,10 +14,6 @@ import requests
 # it is instantiated with a particular project in mind/set, but also has some methods for
 # stuff like searching one
 from .utils import asset_does_not_belong_to_machine
-from .Version import Version
-from packaging.version import InvalidVersion
-
-from .__about__ import __version__
 
 log = logging.getLogger(__name__)
 
@@ -21,6 +21,9 @@ log = logging.getLogger(__name__)
 class ProjectHolder(requests.Session):
     """Generic project holder class abstracts a web-accessible project storage."""
 
+    """List of odd repos where last char is part of version not beta level."""
+    LAST_CHAR_FIX_REQUIRED_ON = []
+
     # web accessible project holders may have single well-known domain usable by everyone
     # in case of GitHub, that is github.com, for Mercurial web gui - here isn't one, etc.
     DEFAULT_HOSTNAME = None
@@ -120,12 +123,20 @@ class ProjectHolder(requests.Session):
             return True
         return False
 
+    def matches_only(self, version):
+        if not self.only:
+            return True
+        if self.only in version:
+            log.info('{} does not match the "only" constraint')
+        return False
+
     def sanitize_version(self, version, pre_ok=False, major=None):
         """Extract version from tag name."""
         log.info("Sanitizing string {} as a satisfying version.".format(version))
         res = False
         try:
-            v = Version(version)
+            char_fix_required = self.repo in self.LAST_CHAR_FIX_REQUIRED_ON
+            v = Version(version, char_fix_required=char_fix_required)
             if not v.is_prerelease or pre_ok:
                 log.info("Parsed as Version OK")
                 log.info("String representation of version is {}.".format(v))
@@ -198,7 +209,7 @@ class ProjectHolder(requests.Session):
             for asset in release['assets']:
                 if assets_filter and not re.search(assets_filter, asset['name']):
                     continue
-                if asset_does_not_belong_to_machine(asset['name']):
+                if not assets_filter and asset_does_not_belong_to_machine(asset['name']):
                     continue
                 urls.append(asset['browser_download_url'])
         else:
