@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # License: BSD, see LICENSE for more details.
 """
-This is the main module of lastversion package. To use it, import it and invoke any function
-documented here. For example:
+This is the main module of lastversion package.
+To use it, import it and invoke any function documented here. For example:
 
 ```python
 from lastversion import lastversion
@@ -16,21 +16,23 @@ import logging
 import os
 import re
 import sys
+
 import yaml
 from appdirs import user_cache_dir
 from cachecontrol import CacheControl
 from cachecontrol.caches.file_cache import FileCache
 # from cachecontrol.heuristics import ExpiresAfter
 from packaging.version import InvalidVersion
-from .Version import Version
-from .GitHubRepoSession import TOKEN_PRO_TIP
 
-from .ProjectHolder import ProjectHolder
+from .GitHubRepoSession import TOKEN_PRO_TIP
 from .HolderFactory import HolderFactory
-from .__about__ import __version__
+from .ProjectHolder import ProjectHolder
+from .Version import Version
+from .argparse_version import VersionAction
 from .utils import download_file, ApiCredentialsError, BadProjectError, rpm_installed_version
 
 log = logging.getLogger(__name__)
+__self__ = "dvershinin/lastversion"
 
 
 def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
@@ -38,6 +40,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     """Find latest release version for a project.
 
     Args:
+        only (str): Only consider tags with this text. Useful for repos with multiple projects
         repo (str): Repository specifier in any form.
         output_format (str): Affects return format. Possible values `version`, `json`, `dict`,
                              `assets`, `source`, `tag`.
@@ -199,11 +202,13 @@ def check_version(value):
 
 
 def parse_version(tag):
+    """Parse version to Version object."""
     h = ProjectHolder()
     return h.sanitize_version(tag, pre_ok=True)
 
 
 def main():
+    """The entrypoint to CLI app."""
     epilog = None
     if "GITHUB_API_TOKEN" not in os.environ and "GITHUB_TOKEN" not in os.environ:
         epilog = TOKEN_PRO_TIP
@@ -219,8 +224,9 @@ def main():
     # affects what is considered last release
     parser.add_argument('--pre', dest='pre', action='store_true',
                         help='Include pre-releases in potential versions')
-    parser.add_argument('--verbose', dest='verbose', action='store_true',
-                        help='Will give you idea of what is happening under the hood')
+    parser.add_argument('-v', '--verbose', action='count', default=0,
+                        help='Will give you an idea of what is happening under the hood, '
+                             '-vv to increase verbosity level')
     # no --download = False, --download filename.tar, --download = None
     parser.add_argument('-d', '--download', dest='download', nargs='?', default=False, const=None,
                         metavar='FILENAME', help='Download with custom filename')
@@ -254,15 +260,14 @@ def main():
                         choices=HolderFactory.HOLDERS.keys())
     parser.add_argument('-y', '--assumeyes', dest='assumeyes', action='store_true',
                         help='Automatically answer yes for all questions')
-    parser.add_argument('--version', action='version',
-                        version='%(prog)s {version}'.format(version=__version__))
+    parser.add_argument('--version', action=VersionAction)
     parser.set_defaults(validate=True, verbose=False, format='version',
                         pre=False, assets=False, newer_than=False, filter=False,
                         shorter_urls=False, major=None, assumeyes=False, at=None)
     args = parser.parse_args()
 
     if args.repo == "self":
-        args.repo = "dvershinin/lastversion"
+        args.repo = __self__
 
     # "expand" repo:1.2 as repo --branch 1.2
     if ':' in args.repo and \
@@ -287,7 +292,12 @@ def main():
 
     if args.verbose:
         logger.setLevel(logging.DEBUG)
-        log.info("Verbose output.")
+        log.info("Verbose {} level output.".format(args.verbose))
+        if args.verbose >= 2:
+            cachecontrol_logger = logging.getLogger('cachecontrol')
+            cachecontrol_logger.removeHandler(logging.NullHandler())
+            cachecontrol_logger.addHandler(ch)
+            cachecontrol_logger.setLevel(logging.DEBUG)
 
     if args.assets:
         args.format = 'assets'
@@ -299,9 +309,14 @@ def main():
         args.filter = re.compile(args.filter)
 
     if args.action == 'test':
-        print(parse_version(args.repo))
-        # TODO dynamic exit status
-        sys.exit(0)
+        v = parse_version(args.repo)
+        if not v:
+            print('Failed to parse as a valid version')
+            sys.exit(1)
+        else:
+            print("Parsed as: {}".format(v))
+            print("Stable: {}".format(not v.is_prerelease))
+            sys.exit(0)
 
     if args.action == 'install':
         # we can only install assets
@@ -318,10 +333,16 @@ def main():
         if args.format != 'assets':
             args.format = 'source'
 
+    base_compare = parse_version(args.repo)
+    if args.newer_than and base_compare:
+        print(max([args.newer_than, base_compare]))
+        sys.exit(2 if base_compare <= args.newer_than else 0)
+
+    res = None
     # other action are either getting release or doing something with release (extend get action)
     try:
-        res = latest(args.repo, args.format, args.pre, args.filter,
-                     args.shorter_urls, args.major, args.only, args.at)
+            res = latest(args.repo, args.format, args.pre, args.filter,
+                         args.shorter_urls, args.major, args.only, args.at)
     except (ApiCredentialsError, BadProjectError) as error:
         sys.stderr.write(str(error) + os.linesep)
         if isinstance(error, ApiCredentialsError) and "GITHUB_API_TOKEN" not in os.environ and \
